@@ -14,6 +14,8 @@ WEATHER_CODE_NAMES.update(
         51: "LIGHT DRIZZLE",
         53: "DRIZZLE",
         55: "DENSE DRIZZLE",
+        56: "LIGHT FREEZING DRIZZLE",
+        57: "FREEZING DRIZZLE",
         61: "SLIGHT RAIN",
         63: "RAIN",
         65: "HEAVY RAIN",
@@ -22,6 +24,7 @@ WEATHER_CODE_NAMES.update(
         71: "LIGHT SNOW",
         73: "SNOW",
         75: "HEAVY SNOW",
+        77: "SNOW GRAINS",
         80: "LIGHT SHOWERS",
         81: "SHOWERS",
         82: "HEAVY SHOWERS",
